pub struct DepositInfo {
    pub token: DepositToken,
    pub deposit: Uint128,
    pub refund_failed_proposals: bool,
}
Information about the deposit required to create a proposal.

Fields

token: DepositToken

The address of the cw20 token to be used for proposal deposits.

deposit: Uint128

The number of tokens that must be deposited to create a proposal.

refund_failed_proposals: bool

If failed proposals should have their deposits refunded.

Implementations

source

impl DepositInfo

source

pub fn into_checked( self, deps: Deps<'_>, dao: Addr ) -> StdResult<CheckedDepositInfo>

Converts deposit info into checked deposit info.