Struct cw_proposal_single::msg::InstantiateMsg
source · pub struct InstantiateMsg {
pub threshold: Threshold,
pub max_voting_period: Duration,
pub min_voting_period: Option<Duration>,
pub only_members_execute: bool,
pub allow_revoting: bool,
pub deposit_info: Option<DepositInfo>,
}Fields
threshold: ThresholdThe threshold a proposal must reach to complete.
max_voting_period: DurationThe default maximum amount of time a proposal may be voted on before expiring.
min_voting_period: Option<Duration>The minimum amount of time a proposal must be open before passing. A proposal may fail before this amount of time has elapsed, but it will not pass. This can be useful for preventing governance attacks wherein an attacker aquires a large number of tokens and forces a proposal through.
only_members_execute: boolIf set to true only members may execute passed proposals. Otherwise, any address may execute a passed proposal.
allow_revoting: boolAllows changing votes before the proposal expires. If this is enabled proposals will not be able to complete early as final vote information is not known until the time of proposal expiration.
deposit_info: Option<DepositInfo>Information about the deposit required to create a proposal. None if there is no deposit requirement, Some otherwise.